NexmarkConfig

Struct NexmarkConfig 

pub struct NexmarkConfig {
Show 35 fields pub active_people: usize, pub in_flight_auctions: usize, pub out_of_order_group_size: usize, pub avg_person_byte_size: usize, pub avg_auction_byte_size: usize, pub avg_bid_byte_size: usize, pub hot_seller_ratio: usize, pub hot_auction_ratio: usize, pub hot_bidder_ratio: usize, pub hot_channel_ratio: usize, pub first_event_id: usize, pub first_event_number: usize, pub base_time: u64, pub num_categories: usize, pub auction_id_lead: usize, pub person_proportion: usize, pub auction_proportion: usize, pub bid_proportion: usize, pub first_auction_id: usize, pub first_person_id: usize, pub first_category_id: usize, pub person_id_lead: usize, pub sine_approx_steps: usize, pub us_states: Vec<String>, pub us_cities: Vec<String>, pub hot_channels: Vec<String>, pub hot_urls: Vec<String>, pub first_names: Vec<String>, pub last_names: Vec<String>, pub num_event_generators: usize, pub rate_shape: RateShape, pub rate_period: usize, pub first_rate: usize, pub next_rate: usize, pub us_per_unit: usize,
}
Nexmark Configuration

Fields

active_people: usize

Maximum number of people to consider as active for placing auctions or bids.

in_flight_auctions: usize

Average number of auction which should be inflight at any time, per generator.

out_of_order_group_size: usize

Number of events in out-of-order groups.

1 implies no out-of-order events. 1000 implies every 1000 events per generator are emitted in pseudo-random order.

avg_person_byte_size: usize

Average idealized size of a ‘new person’ event, in bytes.

avg_auction_byte_size: usize

Average idealized size of a ‘new auction’ event, in bytes.

avg_bid_byte_size: usize

Average idealized size of a ‘bid’ event, in bytes.

hot_seller_ratio: usize

Ratio of auctions for ‘hot’ sellers compared to all other people.

hot_auction_ratio: usize

Ratio of bids to ‘hot’ auctions compared to all other auctions.

hot_bidder_ratio: usize

Ratio of bids for ‘hot’ bidders compared to all other people.

hot_channel_ratio: usize

Ratio of bids for ‘hot’ channels compared to all other channels.

first_event_id: usize

Event id of first event to be generated.

Event ids are unique over all generators, and are used as a seed to generate each event’s data.

first_event_number: usize

First event number.

Generators running in parallel time may share the same event number, and the event number is used to determine the event timestamp.

base_time: u64

Time for first event (ms since epoch).

num_categories: usize

Auction categories.

auction_id_lead: usize

Use to calculate the next auction id.

person_proportion: usize

Person Proportion.

auction_proportion: usize

Auction Proportion.

bid_proportion: usize

Bid Proportion.

first_auction_id: usize

We start the ids at specific values to help ensure the queries find a match even on small synthesized dataset sizes.

first_person_id: usize

We start the ids at specific values to help ensure the queries find a match even on small synthesized dataset sizes.

first_category_id: usize

We start the ids at specific values to help ensure the queries find a match even on small synthesized dataset sizes.

person_id_lead: usize

Use to calculate the next id.

sine_approx_steps: usize

Use to calculate inter_event_delays for rate-shape sine.

us_states: Vec<String>

The collection of U.S. statees

us_cities: Vec<String>

The collection of U.S. cities.

hot_channels: Vec<String>

The collection of hot_channels.

hot_urls: Vec<String>

The collection of hot urls.

first_names: Vec<String>

The collection of first names.

last_names: Vec<String>

The collection of last names.

num_event_generators: usize

Number of event generators to use. Each generates events in its own timeline.

rate_shape: RateShaperate_period: usizefirst_rate: usizenext_rate: usizeus_per_unit: usize